Re: [PATCH v6 2/2] refs.c: SSE4.2 optimizations for check_refname_component
- From
Torsten Bögershausen <tboegi@web.de>
- Date
- Jun 5, 2014, 12:30 UTC
- Message-ID
- <539062D9.60000@web.de>
- In-Reply-To
- <1401916560.18134.167.camel@stross>
On 2014-06-04 23.16, David Turner wrote:
> > Sure! I actually went with > 120k to make measurement easier: > https://github.com/dturner-tw/many-refs
Hm, I didn't get so man
git remote -v origin https://github.com/dturner-tw/many-refs
wc .git/packed-refs
750 1130 38868 .git/packed-refstime git rev-parse HEAD 7ac416f789fd4f1e398449113f6e1ec1d699141a
real 0m0.008s user 0m0.002s sys 0m0.004s
where only patch 1/2 doesn't seem to speed up things on my system:
time ~/projects/git/tb.140604_DavidTurner_SSE4/git rev-parse HEAD 7ac416f789fd4f1e398449113f6e1ec1d699141a
real 0m0.010s user 0m0.002s sys 0m0.005s
Intel Core Duo @ 2.4 Ghz, Mac OS
(and I get similar values under an AMD Dual core running 2Ghz under Linux)